#
# spec file for package pgaudit
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# name_pg uses --keep-name-conditionals (argument of spec_query)
# loophole
%define         name_pg  postgresql13%{nil}
# the name_pg define is needed internally by pg_* macros - but we can't use it in conditions
%define         pg_name %name_pg
%define         ext_name    pgaudit
%{pg_version_from_name}

%if "%{name_pg}" == ""
# nill flavour
Name:           pgaudit
ExclusiveArch:  do_not_build
%else
Name:           %{name_pg}-pgaudit
%endif
%if "%{name_pg}" == "postgresql12"
Version:        1.4.3
%endif
%if "%{name_pg}" == "postgresql13"
Version:        1.5.2
%endif
# you need to update both the Version: field and the define below for the factory check
%if "%{name_pg}" == "postgresql14"
Version:        1.6.2
%endif
%if "%{name_pg}" == "postgresql15"
Version:        1.7.0
%endif
%if "%{name_pg}" == "postgresql16"
Version:        16.0
%endif
Release:        5.1
Summary:        An auditing module for PostgreSQL
License:        PostgreSQL
Group:          Productivity/Databases/Tools
URL:            https://github.com/pgaudit/pgaudit
%if "%{name_pg}" != ""
# not nill flavour
Source:         %https://github.com/pgaudit/pgaudit/archive/refs/tags/%{version}.tar.gz#/%{ext_name}-%{version}.tar.gz
%else
# Track the existance of get-tars
Source99:       get-tars
%endif

BuildRequires:  %{pg_name}-llvmjit-devel
%pg_server_requires
%if "%{name_pg}" == ""
ExclusiveArch:  do_not_build
%endif

%description
This is the initial version of an auditing module for Postgres.

It collects audit events from various sources and logs them in CSV format
including a timestamp, user information, details of objects affected (if any),
and the fully-qualified command text (whenever available).

All DDL, DML (including SELECT), and utility commands are supported. These
are categorised as described below, and audit logging for each group of
commands may be enabled or disabled by the superuser. Once enabled, however,
audit logging may not be disabled by a user.

%prep
%autosetup -p1 -n %{ext_name}-%{version}

%build
%make_pgxs

%install
%make_pgxs_install

%files
%doc README.md LICENSE sql/
%{pg_config_pkglibdir}/%{ext_name}.so
%{pg_config_sharedir}/extension/%{ext_name}*
%if %{postgresql_has_llvm}
%{pg_config_pkglibdir}/bitcode/*
%endif

%changelog
* Fri May 17 2024 Reinhard Max <max@suse.com>
- PostgreSQL 11 is EOL.
* Wed Sep  6 2023 Marcus Rueckert <mrueckert@suse.de>
- Added version 16 for postgresql 16
  https://github.com/pgaudit/pgaudit/releases/tag/16.0
* Wed Apr 19 2023 Reinhard Max <max@suse.com>
- PostgreSQL 10 is EOL.
* Tue Jan 31 2023 Marcus Rueckert <mrueckert@suse.de>
- added 1.7.0 to enable pg 15
* Thu Sep 22 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Hack up spec file a bit to get over source_validator, we rely on
  + name_pg uses --keep-name-conditionals (argument of spec_query)
  + but wre also need pg_name defined for the pg_* macros, as they
    refer to it. So we define both, and use name_pg for the
    conditions.
* Mon Mar 21 2022 pgajdos@suse.com
- version update to 1.2.4, 1.3.4, 1.4.3, 1.5.2, 1.6.2
  * Bug Fix: Skip logging script statements for create/alter extension.
- added sources
  + get-tars
* Thu Dec  2 2021 Marcus Rueckert <mrueckert@suse.de>
- fix postgresql_has_llvm usage
* Tue Nov 30 2021 Marcus Rueckert <mrueckert@suse.de>
- switch to %%{pg_name}-llvmjit-devel
* Sun Nov 14 2021 Marcus Rueckert <mrueckert@suse.de>
- remove some unneeded pg_name conditionals
* Sun Nov 14 2021 Marcus Rueckert <mrueckert@suse.de>
- Update versions (1.2.3, 1.3.3, 1.4.2, 1.5.1)
  - Guard against search-path based attacks.
  - Add security definer and search_path to event trigger functions.
- Add 1.6.1 for postgresql 14
  - 1.6.0: https://github.com/pgaudit/pgaudit/releases/tag/1.6.0
  - 1.6.1: https://github.com/pgaudit/pgaudit/releases/tag/1.6.1
- port to postgresql macros
- drop support for pg < 10
* Wed Jun 30 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do no longer build postgresql95 and postgresql96 flavors on
  Tumbleweed.
* Wed Nov  4 2020 pgajdos@suse.com
- try to make factory bot happy
* Tue Nov  3 2020 pgajdos@suse.com
- revert last change, keep flavours unresolved
* Wed Oct 21 2020 pgajdos@suse.com
- do not build favours that would be unresolved in standard repos
* Tue Oct 20 2020 pgajdos@suse.com
- version update
  - 1.0.8: https://github.com/pgaudit/pgaudit/releases/tag/1.0.8
  - 1.1.3: https://github.com/pgaudit/pgaudit/releases/tag/1.1.3
  - 1.2.2: https://github.com/pgaudit/pgaudit/releases/tag/1.2.2
  - 1.3.2: https://github.com/pgaudit/pgaudit/releases/tag/1.3.2
  - 1.4.1: https://github.com/pgaudit/pgaudit/releases/tag/1.4.1
* Fri Sep 25 2020 Marcus Rueckert <mrueckert@suse.de>
- added pg 13 support by adding 1.5.0
  https://github.com/pgaudit/pgaudit/releases/tag/1.5.0
* Wed May  6 2020 Marcus Rueckert <mrueckert@suse.de>
- we added support for newer pg versions but never enabled them in
  the multibuild
* Tue Oct 22 2019 Marcus Rueckert <mrueckert@suse.de>
- bump package for existing versions and add support for newer pg
  versions:
  - 1.0.7: https://github.com/pgaudit/pgaudit/releases/tag/1.0.7
  - 1.1.2: https://github.com/pgaudit/pgaudit/releases/tag/1.1.2
  - 1.2.1: https://github.com/pgaudit/pgaudit/releases/tag/1.2.1
  - 1.3.1: https://github.com/pgaudit/pgaudit/releases/tag/1.3.1
  - 1.4.0: https://github.com/pgaudit/pgaudit/releases/tag/1.4.0
* Fri Sep  8 2017 mrueckert@suse.de
- make the file lists less broad:
  - BR the -server package so we get the owner of
    %%{_datadir}/postgresql*/extension/
  - only own files really from this package
* Fri Aug  4 2017 mrueckert@suse.de
- use multibuild
- update to 1.0.6 and 1.1.1 respectively
* Thu Feb 19 2015 mrueckert@suse.de
- update to git HEAD: (adds HEAD.patch)
  - 9bdc2e8 Use bms_{copy,first_member,free} on
    rte->{selected,modified}Cols
  - 869f4e7 Take column-level privileges into account too
  - 715b653 If audit has been granted permissions, we log the event
  - 7d9313c Make should_be_logged() authoritative by itself
  - 58aa1f4 Describe the current behaviour more precisely
  - 43f9baf If no roles are given, all roles are audited
  - c0b4e6d Add pgaudit.roles setting
  - fe5219f Rename T_AlterTableSpaceMoveStmt to
    T_AlterTableMoveAllStmt following 3c4cf08
  - 98eb0ed We don't need the [] wrapper
  - ab43873 Remove GUC source checking altogether
  - 7782701 Fixes for META.json
* Tue Oct  7 2014 darin@darins.net
- fixed %%files path for SLES
* Mon Oct  6 2014 darin.perusich@ctg.com
- Initial packaging of pgaudit
